//gulpfile.js
// les dépendances du fichier gulp
const { src, dest , series , watch } = require("gulp");
const sass = require("gulp-sass");
const rename = require("gulp-rename");
const del = require('del');
const autoprefixer = require('gulp-autoprefixer');
const browserSync = require('browser-sync');

sass.compiler = require("node-sass");

// ---------------------------
// ---------------------------

// task 1 : supprimer le fichier style.css
function cleanTask(){
  return del("./style.css");
}

// task2 : compiler les fichiers dans le dossier scss => style.css
function sassTask(){
  const flags = {outputStyle: 'compressed'};
  return src("scss/**/*.scss")
  .pipe(sass(flags).on('error', sass.logError))
  .pipe(rename("./style.css"))
  .pipe(dest("./"));
}

// task3 : ajouter les vendors prefix sur les règles css pour le fichier style.css
// voir le fichier package.json pour voir les paramètres 
function autoprefixerTask(){
  return src("./style.css")
  .pipe(autoprefixer())
  .pipe(dest("."));
}

// task4 : mettre en série les tasks 1, 2 et 3
// pas possible serie() dans une fonction, il FAUT l'associer à une variable 
const run = series( cleanTask , sassTask , autoprefixerTask ); 

// task5 : si modification dans le dossier scss , lancer la task4
function watchTask(){
  watch("scss/**/*.scss" , run);
}

// task6 : créer un server local BrowserSync 
// si modifications dans le dossier scss => mettre en serie task 2 et 3
// si modification du fichier index.html ou style.css => relancer BrowserSync 
function serverTask(){
  const server = browserSync.create();
  server.init({
        server: {
            baseDir: "./"
        }
    });
  watch("scss/**/*.scss" , series(sassTask , autoprefixerTask));
  watch(["index.html", "style.css"]).on('change', server.reload);
}

// ---------------------------
// ---------------------------

// Ensemble des tâches pouvant être appelée via la commande npx gulp 
module.exports = {
  sass : sassTask,
  clean : cleanTask ,
  run : run,
  default : watchTask,
  server : serverTask
}

